@@ -45,14 +45,6 @@ static gsize       volatile trash_empty_deleted_files;
 static gsize       volatile trash_empty_total_files;
 static gboolean    volatile trash_empty_update_pending;
 
-static gboolean
-trash_empty_clear_pending (gpointer user_data)
-{
-  trash_empty_update_pending = FALSE;
-
-  return FALSE;
-}
-
 static gboolean
 trash_empty_update_dialog (gpointer user_data)
 {
@@ -244,10 +236,7 @@ trash_empty_start (GtkWidget *parent)
   GtkBuilder *builder;
   gint i;
 
-  builder = gtk_builder_new ();
-  gtk_builder_add_from_file (builder,
-                             GTK_BUILDERDIR "/trashapplet-empty-progress.ui",
-                             NULL);
+  builder = gtk_builder_new_from_resource (GRESOURCE "trashapplet-empty-progress.ui");
 
   for (i = 0; i < G_N_ELEMENTS (widgets); i++)
     {
