@@ -36,9 +36,12 @@
 #include "trash-empty.h"
 #include "xstuff.h"
 
-typedef MatePanelAppletClass TrashAppletClass;
+#define TRASH_TYPE_APPLET (trash_applet_get_type ())
 
-typedef struct
+G_DECLARE_FINAL_TYPE (TrashApplet, trash_applet,
+                      TRASH, APPLET, MatePanelApplet)
+
+struct _TrashApplet
 {
   MatePanelApplet applet;
 
@@ -48,12 +51,9 @@ typedef struct
   GtkImage *image;
   GIcon *icon;
   gint items;
-} TrashApplet;
+};
 
 G_DEFINE_TYPE (TrashApplet, trash_applet, PANEL_TYPE_APPLET);
-#define TRASH_TYPE_APPLET (trash_applet_get_type ())
-#define TRASH_APPLET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
-                           TRASH_TYPE_APPLET, TrashApplet))
 
 static void trash_applet_do_empty    (GtkAction   *action,
                                       TrashApplet *applet);
@@ -211,15 +211,11 @@ trash_applet_dispose (GObject *object)
 static void
 trash_applet_init (TrashApplet *applet)
 {
-  const GtkTargetEntry drop_types[] = { { "text/uri-list" } };
+  const GtkTargetEntry drop_types[] = { { "text/uri-list", 0, 0 } };
 
   /* needed to clamp ourselves to the panel size */
   mate_panel_applet_set_flags (MATE_PANEL_APPLET (applet), MATE_PANEL_APPLET_EXPAND_MINOR);
 
-  /* enable transparency hack */
-  mate_panel_applet_set_background_widget (MATE_PANEL_APPLET (applet),
-                                      GTK_WIDGET (applet));
-
   /* setup the image */
   applet->image = g_object_ref_sink (GTK_IMAGE (gtk_image_new ()));
   gtk_container_add (GTK_CONTAINER (applet),
@@ -343,7 +339,7 @@ error_dialog (TrashApplet *applet, const gchar *error, ...)
                                    GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
                                    "%s", error_string);
 
-  g_signal_connect (G_OBJECT (dialog), "response",
+  g_signal_connect (dialog, "response",
                     G_CALLBACK (gtk_widget_destroy),
                     NULL);
 
@@ -433,7 +429,7 @@ trash_applet_show_about (GtkAction   *action,
                          "version", VERSION,
                          "copyright", _("Copyright \xc2\xa9 2004 Michiel Sikkes\n"
                                         "Copyright \xc2\xa9 2008 Ryan Lortie\n"
-                                        "Copyright \xc2\xa9 2012-2020 MATE developers"),
+                                        "Copyright \xc2\xa9 2012-2021 MATE developers"),
                          "comments", _("A MATE trash bin that lives in your panel. "
                                        "You can use it to view the trash or drag "
                                        "and drop items into the trash."),
@@ -620,7 +616,6 @@ trash_applet_factory (MatePanelApplet *applet,
   if (!strcmp (iid, "TrashApplet"))
     {
       GtkActionGroup *action_group;
-      gchar          *ui_path;
 
       g_set_application_name (_("Trash Applet"));
 
@@ -633,9 +628,9 @@ trash_applet_factory (MatePanelApplet *applet,
 				    trash_applet_menu_actions,
 				    G_N_ELEMENTS (trash_applet_menu_actions),
 				    applet);
-      ui_path = g_build_filename (TRASH_MENU_UI_DIR, "trashapplet-menu.xml", NULL);
-      mate_panel_applet_setup_menu_from_file (applet, ui_path, action_group);
-      g_free (ui_path);
+      mate_panel_applet_setup_menu_from_resource (applet,
+                                                  GRESOURCE "trashapplet-menu.xml",
+                                                  action_group);
       g_object_unref (action_group);
 
       gtk_widget_show (GTK_WIDGET (applet));
